@@ -7,7 +7,12 @@ from chargebee.models.coupon_set import CouponSet
 from chargebee.models.customer import Customer
 from chargebee.models.event import Event
 from chargebee.models.hosted_page import HostedPage
+from chargebee.models.item import Item
+from chargebee.models.item_family import ItemFamily
+from chargebee.models.item_price import ItemPrice
 from chargebee.models.invoice import Invoice
+from chargebee.models.attached_item import AttachedItem
+from chargebee.models.differential_price import DifferentialPrice
 from chargebee.models.credit_note import CreditNote
 from chargebee.models.order import Order
 from chargebee.models.estimate import Estimate
@@ -32,6 +37,12 @@ from chargebee.models.contact import Contact
 from chargebee.models.export import Export
 from chargebee.models.gift import Gift
 from chargebee.models.quote import Quote
-from chargebee.models.content import Content
 from chargebee.models.hierarchy import Hierarchy
-from chargebee.models.payment_intent import PaymentIntent
\ No newline at end of file
+from chargebee.models.payment_intent import PaymentIntent
+from chargebee.models.usage import Usage
+from chargebee.models.contract_term import ContractTerm
+from chargebee.models.advance_invoice_schedule import AdvanceInvoiceSchedule
+from chargebee.models.token import Token
+from chargebee.models.quoted_subscription import QuotedSubscription
+from chargebee.models.quote_line_group import QuoteLineGroup
+from chargebee.models.content import Content
\ No newline at end of file
