@@ -22,17 +22,24 @@ class Customer(Model):
     class Relationship(Model):
       fields = ["parent_id", "payment_owner_id", "invoice_owner_id"]
       pass
+    class ParentAccountAccess(Model):
+      fields = ["portal_edit_child_subscriptions", "portal_download_child_invoices", "send_subscription_emails", "send_invoice_emails", "send_payment_emails"]
+      pass
+    class ChildAccountAccess(Model):
+      fields = ["portal_edit_subscriptions", "portal_download_invoices", "send_subscription_emails", "send_invoice_emails", "send_payment_emails"]
+      pass
 
     fields = ["id", "first_name", "last_name", "email", "phone", "company", "vat_number", "auto_collection", \
-    "net_term_days", "vat_number_validated_time", "vat_number_status", "allow_direct_debit", "is_location_valid", \
-    "created_at", "created_from_ip", "exemption_details", "taxability", "entity_code", "exempt_number", \
-    "resource_version", "updated_at", "locale", "consolidated_invoicing", "billing_date", "billing_date_mode", \
-    "billing_day_of_week", "billing_day_of_week_mode", "pii_cleared", "card_status", "fraud_flag", \
-    "primary_payment_source_id", "backup_payment_source_id", "billing_address", "referral_urls", \
-    "contacts", "payment_method", "invoice_notes", "preferred_currency_code", "promotional_credits", \
+    "offline_payment_method", "net_term_days", "vat_number_validated_time", "vat_number_status", \
+    "allow_direct_debit", "is_location_valid", "created_at", "created_from_ip", "exemption_details", \
+    "taxability", "entity_code", "exempt_number", "resource_version", "updated_at", "locale", "billing_date", \
+    "billing_date_mode", "billing_day_of_week", "billing_day_of_week_mode", "pii_cleared", "auto_close_invoices", \
+    "card_status", "fraud_flag", "primary_payment_source_id", "backup_payment_source_id", "billing_address", \
+    "referral_urls", "contacts", "payment_method", "invoice_notes", "preferred_currency_code", "promotional_credits", \
     "unbilled_charges", "refundable_credits", "excess_payments", "balances", "meta_data", "deleted", \
-    "registered_for_gst", "customer_type", "business_customer_without_vat_number", "client_profile_id", \
-    "relationship"]
+    "registered_for_gst", "consolidated_invoicing", "customer_type", "business_customer_without_vat_number", \
+    "client_profile_id", "relationship", "use_default_hierarchy_settings", "parent_account_access", \
+    "child_account_access", "vat_number_prefix"]
 
 
     @staticmethod
@@ -96,7 +103,7 @@ class Customer(Model):
         return request.send('post', request.uri_path("customers",id,"record_excess_payment"), params, env, headers)
 
     @staticmethod
-    def collect_payment(id, params=None, env=None, headers=None):
+    def collect_payment(id, params, env=None, headers=None):
         return request.send('post', request.uri_path("customers",id,"collect_payment"), params, env, headers)
 
     @staticmethod
@@ -130,3 +137,7 @@ class Customer(Model):
     @staticmethod
     def hierarchy(id, params=None, env=None, headers=None):
         return request.send('get', request.uri_path("customers",id,"hierarchy"), params, env, headers)
+
+    @staticmethod
+    def update_hierarchy_settings(id, params=None, env=None, headers=None):
+        return request.send('post', request.uri_path("customers",id,"update_hierarchy_settings"), params, env, headers)
