@@ -26,6 +26,10 @@ class VirtualBankAccount(Model):
     def list(params=None, env=None, headers=None):
         return request.send_list_request('get', request.uri_path("virtual_bank_accounts"), params, env, headers)
 
+    @staticmethod
+    def delete(id, env=None, headers=None):
+        return request.send('post', request.uri_path("virtual_bank_accounts",id,"delete"), None, env, headers)
+
     @staticmethod
     def delete_local(id, env=None, headers=None):
         return request.send('post', request.uri_path("virtual_bank_accounts",id,"delete_local"), None, env, headers)
